==> v_alpha4.0.zip: tizenbuildtools/qtcreator/build_and_deploy_tizen_plugin.sh <==
#!/bin/bash

CUR_DIR=$PWD

SCRIPT_DIR=$(dirname $0)
cd $SCRIPT_DIR
SCRIPT_DIR=$PWD
cd ..
git submodule init
git submodule update
cd $SCRIPT_DIR

set -e

if [ -z "$QTC_BUILD" ]; then
    echo "undefined QTC_BUILD environment variable"
    exit 1;
fi
QT_CREATOR_VERSION_OUTPUT=$("$QTC_BUILD"/bin/qtcreator -version 2>&1)

QT_CREATOR_VERSION=$(echo $QT_CREATOR_VERSION_OUTPUT | grep -o "Qt Creator [0-9][0-9\.]*" | grep -o "[0-9\.]*")



QT_CREATOR_QT_VERSION=$(echo $QT_CREATOR_VERSION_OUTPUT | grep -o "based on Qt [0-9][0-9\.]*" | grep -o "[0-9\.]*")
QT_CREATOR_QT_MAJOR_VERSION=$(echo $QT_CREATOR_QT_VERSION | cut -d . -f1)

QMAKE_QT_PATH_VERSION=$(qmake -version | grep -o "Using Qt version [0-9\.]*" | grep -o "[0-9\.]*")

QMAKE_QT_PATH_MAJOR_VERSION=$(echo $QMAKE_QT_PATH_VERSION | cut -d . -f1)

if [ "$QT_CREATOR_QT_MAJOR_VERSION" != "$QMAKE_QT_PATH_MAJOR_VERSION" ]; then
    echo "qmake Qt version ($QMAKE_QT_PATH_VERSION) is not compatible with Qt used by Qt creator($QT_CREATOR_QT_VERSION)"
    exit 1
fi

echo found Qt Creator - version $QT_CREATOR_VERSION build with Qt $QT_CREATOR_QT_VERSION in $QTC_BUILD

if [ -z "$QTC_SOURCE" ]; then
    if [ ! -d qt-creator-sources ]; then
        echo "undefined QTC_SOURCE environment variable and no qt-creator directory in $SCRIPT_DIR. Downloading creator sources for Qt Creator $QT_CREATOR_VERSION"
        git clone http://git.gitorious.org/qt-creator/qt-creator.git -b v$QT_CREATOR_VERSION qt-creator-sources
    else
        QTC_SOURCE=$PWD
    fi
    cd qt-creator-sources
    QTC_SOURCE=$PWD

fi

echo Qt Creator source set to $QTC_SOURCE

export QTC_BUILD
export QTC_SOURCE

cd $SCRIPT_DIR/plugins/tizen
qmake -r
make


cd "$CUR_DIR"

==> v_alpha6.1.zip: tizenbuildtools/qtcreator/build_and_deploy_tizen_plugin.sh <==
#!/bin/bash

CUR_DIR=$PWD

SCRIPT_DIR=$(dirname $0)
cd $SCRIPT_DIR
SCRIPT_DIR=$PWD
cd ..
git submodule init
git submodule update
cd $SCRIPT_DIR

set -e

if [ -z "$QTC_BUILD" ]; then
    echo "undefined QTC_BUILD environment variable"
    exit 1;
fi
export DISPLAY=:0

QT_CREATOR_VERSION_OUTPUT=$("$QTC_BUILD"/bin/qtcreator -version 2>&1)
QT_CREATOR_VERSION=$(echo $QT_CREATOR_VERSION_OUTPUT | grep -o "Qt Creator [0-9][0-9\.]*" | grep -o "[0-9\.]*")

QT_CREATOR_QT_VERSION=$(echo $QT_CREATOR_VERSION_OUTPUT | grep -o "based on Qt [0-9][0-9\.]*" | grep -o "[0-9\.]*")
QT_CREATOR_QT_MAJOR_VERSION=$(echo $QT_CREATOR_QT_VERSION | cut -d . -f1)

QMAKE_QT_PATH_VERSION=$(qmake -version | grep -o "Using Qt version [0-9\.]*" | grep -o "[0-9\.]*")

QMAKE_QT_PATH_MAJOR_VERSION=$(echo $QMAKE_QT_PATH_VERSION | cut -d . -f1)

if [ "$QT_CREATOR_QT_MAJOR_VERSION" != "$QMAKE_QT_PATH_MAJOR_VERSION" ]; then
    echo "qmake Qt version ($QMAKE_QT_PATH_VERSION) is not compatible with Qt used by Qt creator($QT_CREATOR_QT_VERSION)"
    exit 1
fi

if [[ "$QT_CREATOR_VERSION" != "3"* ]]; then
    echo "The plugin is compatible only with QtCreator 3.* version"
    exit 1
fi

echo found Qt Creator - version $QT_CREATOR_VERSION build with Qt $QT_CREATOR_QT_VERSION in $QTC_BUILD

if [ -z "$QTC_SOURCE" ]; then
    if [ ! -d qt-creator-sources ]; then
        echo "undefined QTC_SOURCE environment variable and no qt-creator directory in $SCRIPT_DIR. Downloading creator sources for Qt Creator $QT_CREATOR_VERSION"
	QT_CREATOR_BRANCH=${QT_CREATOR_VERSION:0:-2}
        git clone http://git.gitorious.org/qt-creator/qt-creator.git -b $QT_CREATOR_BRANCH qt-creator-sources
	cd qt-creator-sources
	git checkout v$QT_CREATOR_VERSION
	cd ..
    else
        QTC_SOURCE=$PWD
    fi
    cd qt-creator-sources
    QTC_SOURCE=$PWD
fi

echo Qt Creator source set to $QTC_SOURCE

export QTC_BUILD
export QTC_SOURCE

cd $SCRIPT_DIR/plugins/tizen

QTCREATOR_TIZEN_PLUGIN_BRANCH=${QT_CREATOR_VERSION:0:-2}

CONTAINS_BRANCH=$(git branch -r | grep -c "origin/$QTCREATOR_TIZEN_PLUGIN_BRANCH")
if [ "$CONTAINS_BRANCH" == "0" ]; then
    echo "There is no Tizen plugin for QtCreator: $QTCREATOR_TIZEN_PLUGIN_BRANCH"
    exit 1;
fi

git reset --hard origin/$QTCREATOR_TIZEN_PLUGIN_BRANCH

qmake -r
make


cd "$CUR_DIR"
